@@ -1,7 +1,7 @@
 package Bot::ChatBots::Telegram::WebHook;
 use strict;
 use warnings;
-{ our $VERSION = '0.008'; }
+{ our $VERSION = '0.009'; }
 
 use Ouch;
 use Log::Any qw< $log >;
@@ -15,8 +15,8 @@ use namespace::clean;
 with 'Bot::ChatBots::Telegram::Role::Source';    # has normalize_record
 with 'Bot::ChatBots::Role::WebHook';
 
-has auto_register => (is => 'ro', default => 0, ini_arg => 'register');
-has auto_unregister => (is => 'ro', default => 0, ini_arg => 'unregister');
+has auto_register => (is => 'ro', default => 0, init_arg => 'register');
+has auto_unregister => (is => 'ro', default => 0, init_arg => 'unregister');
 
 sub BUILD {
    my $self = shift;
@@ -78,7 +78,10 @@ sub register {
       $wh_url = $c->url_for($path);
    } ## end else [ if (my $url = $args->{...})]
 
-   my $form = {url => $wh_url->to_abs->to_string};
+   my $wh_url_string = $wh_url->to_abs->to_string;
+   $log->info("registering bot URI $wh_url_string");
+   my $form = {url => $wh_url_string};
+
    if ($self->{certificate}) {
       my $certificate = $args->{certificate};
       $certificate = {content => $certificate} unless ref $certificate;
